<?php
/**
 * TGMPA Required Plugins.
 *
 * Register recommended plugins for this theme.
 *
 * @package York Lite
 * @author  Rich Tabor of ThemeBeans <hello@themebeans.com>
 * @license http://www.gnu.org/licenses/gpl-3.0.html GNU Public License
 */

/**
 * Load the TGMPA class.
 */
require get_parent_theme_file_path( '/inc/class-tgm-plugin-activation.php' );

/**
 * Register the recommended plugins for this theme.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function york_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		array(
			'name'     => esc_html__( 'CoBlocks', 'york-lite' ),
			'slug'     => 'coblocks',
			'required' => false,
		),
		array(
			'name'     => esc_html__( 'Block Gallery', 'york-lite' ),
			'slug'     => 'block-gallery',
			'required' => false,
		),
		array(
			'name'     => esc_html__( 'Portfolio Post Type', 'york-lite' ),
			'slug'     => 'portfolio-post-type',
			'required' => false,
		),
		array(
			'name'     => esc_html__( 'Login Designer', 'york-lite' ),
			'slug'     => 'login-designer',
			'required' => false,
		),
	);

	// Let's check if the block editor is activated.
	if ( ! function_exists( 'register_block_type' ) ) {

		$gutenberg = array(
			array(
				'name'     => esc_html__( 'Gutenberg', 'york-lite' ),
				'slug'     => 'gutenberg',
				'required' => false,
			),
		);

		// Combine the two arrays.
		$args = array_merge( $args, $gutenberg );
	}

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'york-lite',          // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be at the top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}

add_action( 'tgmpa_register', 'york_register_required_plugins' );
